diff --git a/source/Lib/DecoderLib/DecLib.cpp b/source/Lib/DecoderLib/DecLib.cpp
index 6d50247a3e618e46df9ae719ca34c0dfe020eae9..c98866dd232059fa895e05e0290e227febf50f53 100644
--- a/source/Lib/DecoderLib/DecLib.cpp
+++ b/source/Lib/DecoderLib/DecLib.cpp
@@ -846,8 +846,9 @@ void DecLib::executeLoopFilters()
 #endif
 
 #if JVET_AJ0188_CODING_INFO_CLASSIFICATION
-  PelUnitBuf codingInfoBuf = m_cALF.callCodingInfoBuf( cs );
-  m_cLoopFilter.loopFilterPic( cs, codingInfoBuf, true );
+  const bool storeCodingInfo = cs.sps->getALFEnabledFlag();
+  PelUnitBuf codingInfoBuf = storeCodingInfo ? m_cALF.callCodingInfoBuf( cs ) : PelUnitBuf();
+  m_cLoopFilter.loopFilterPic( cs, codingInfoBuf, storeCodingInfo );
 #else
   m_cLoopFilter.loopFilterPic( cs );
 #endif
diff --git a/source/Lib/EncoderLib/EncGOP.cpp b/source/Lib/EncoderLib/EncGOP.cpp
index 6fe1c5fb3317e0788063858dc4d419335afe58e4..1342e6ea9ee39333369e4655348c866608fd6bfb 100644
--- a/source/Lib/EncoderLib/EncGOP.cpp
+++ b/source/Lib/EncoderLib/EncGOP.cpp
@@ -3904,8 +3904,9 @@ void EncGOP::compressGOP(int iPOCLast, int iNumPicRcvd, PicList &rcListPic, std:
 #endif
 
 #if JVET_AJ0188_CODING_INFO_CLASSIFICATION
-      PelUnitBuf codingInfoBuf = m_pcALF->callCodingInfoBuf( cs );
-      m_pcLoopFilter->loopFilterPic( cs, codingInfoBuf, true );
+      const bool storeCodingInfo = cs.sps->getALFEnabledFlag();
+      PelUnitBuf codingInfoBuf = storeCodingInfo ? m_pcALF->callCodingInfoBuf( cs ) : PelUnitBuf();
+      m_pcLoopFilter->loopFilterPic( cs, codingInfoBuf, storeCodingInfo );
 #else
       m_pcLoopFilter->loopFilterPic( cs );
 #endif
@@ -5183,8 +5184,9 @@ uint64_t EncGOP::preLoopFilterPicAndCalcDist( Picture* pcPic )
 #endif
 
 #if JVET_AJ0188_CODING_INFO_CLASSIFICATION
-  PelUnitBuf codingInfoBuf = m_pcALF->callCodingInfoBuf( cs );
-  m_pcLoopFilter->loopFilterPic( cs, codingInfoBuf, false );
+  const bool storeCodingInfo = false;
+  PelUnitBuf codingInfoBuf = storeCodingInfo ? m_pcALF->callCodingInfoBuf( cs ) : PelUnitBuf();
+  m_pcLoopFilter->loopFilterPic( cs, codingInfoBuf, storeCodingInfo );
 #else
   m_pcLoopFilter->loopFilterPic( cs );
 #endif
diff --git a/source/Lib/EncoderLib/EncCu.cpp b/source/Lib/EncoderLib/EncCu.cpp
index 462a206400310afcb657862d62a16cfd937a7400..fdec1cc10fdc082fc8cffbdeebaf5d9f29d81ffc 100644
--- a/source/Lib/EncoderLib/EncCu.cpp
+++ b/source/Lib/EncoderLib/EncCu.cpp
@@ -24881,8 +24881,8 @@ void EncCu::xCalDebCost( CodingStructure &cs, Partitioner &partitioner, bool cal
     {
       m_pcLoopFilter->resetFilterLengths();
 #if JVET_AJ0188_CODING_INFO_CLASSIFICATION
-      //No Impact on OBMC Buffer
-      m_pcLoopFilter->xDeblockCU( *cu, EDGE_VER, false, m_tempWoOBMCBuffer );
+      //No impact on CIIP buffer
+      m_pcLoopFilter->xDeblockCU( *cu, EDGE_VER, false, m_ciipBuffer[0] );
 #else
       m_pcLoopFilter->xDeblockCU( *cu, EDGE_VER );
 #endif
@@ -24892,8 +24892,8 @@ void EncCu::xCalDebCost( CodingStructure &cs, Partitioner &partitioner, bool cal
     {
       m_pcLoopFilter->resetFilterLengths();
 #if JVET_AJ0188_CODING_INFO_CLASSIFICATION
-      //No Impact on OBMC Buffer
-      m_pcLoopFilter->xDeblockCU( *cu, EDGE_HOR, false, m_tempWoOBMCBuffer );
+      //No impact on CIIP buffer
+      m_pcLoopFilter->xDeblockCU( *cu, EDGE_HOR, false, m_ciipBuffer[0] );
 #else
       m_pcLoopFilter->xDeblockCU( *cu, EDGE_HOR );
 #endif